==> Epics.uv8.74.tar.gz: prog/Mu/epmuInte.f <==
      subroutine epmuInte
      implicit none
#include  "ZepTrackv.h"
#include  "ZepTrackp.h"
#include  "Zcode.h"
      
      real*8 Et

      if( Move.proc .eq. 'pair' ) then
         call epmuPrsmpE(Media(MediaNo), Move.Track.p.fm.p(4),
     *                   Et)
         cTrack.p.fm.p(4) = cTrack.p.fm.p(4) - Et  ! muon
         call epe2p(cTrack)         ! adjust momentum
         call eppush(cTrack)        ! push
         if(Media(MediaNo).mu.MuPr .eq. 3) then
c              generate pair electrons; employ eppair
c              to do so, make cTrack a gamma of energy Et
            cTrack.p.fm.p(4) = Et
            call cmkptc(kphoton, 0, 0, cTrack.p)
            call epe2p(cTrack)       ! this may not be needed ; for safety
            call eppair
         endif
      elseif( Move.proc .eq. 'brem' ) then   
         call epmuBrsmpE(Media(MediaNo), Move.Track.p.fm.p(4),
     *                   Et)
         cTrack.p.fm.p(4) = cTrack.p.fm.p(4) - Et  ! muon
         call epe2p(cTrack)         ! adjust momentum
         call eppush(cTrack)        ! push
         if(Media(MediaNo).mu.MuBr .eq. 3) then
c             generate brems gamma; no deflection
            cTrack.p.fm.p(4) = Et
            call cmkptc(kphoton, kcasg, 0, cTrack.p)
            call epe2p(cTrack)  ! adjust momentum
            call eppush(cTrack) ! push
         endif
      elseif( Move.proc .eq. 'nuci' ) then   
         call epmuNsmpE(Media(MediaNo), Move.Track.p.fm.p(4),
     *                   Et)
         cTrack.p.fm.p(4) = cTrack.p.fm.p(4) - Et  ! muon
         call epe2p(cTrack)         ! adjust momentum
         call eppush(cTrack)        ! push
         if(Media(MediaNo).mu.MuNI .eq. 3 .and. Et .gt. 150.d-3) then
c             generate gamma-N interaction; employ gamma interaction
c             routine 
            cTrack.p.fm.p(4) = Et
            call cmkptc( kphoton, 0, 0, cTrack.p)
            call epe2p(cTrack)  ! adjust momentum
c            mediateAeff=Media(MediaNo).Aeff
c            mediateZeff=Media(MediaNo).Zeff
c
            call ep2cosPtcl( cTrack.p )
            call ep2cosCond2(Media(MediaNo).Aeff,
     *                       Media(MediaNo).Zeff)
            call cphotop        ! Cosmos function
            call eppushPtcl(cTrack) ! use pos. info from this ptcl
         endif
      endif   
      end

==> Epics.uv8.76.tar.gz: prog/Mu/epmuInte.f <==
      subroutine epmuInte
      implicit none
#include  "ZepTrackv.h"
#include  "ZepTrackp.h"
#include  "Zcode.h"
      
      real*8 Et

      if( Move.proc .eq. 'pair' ) then
         call epmuPrsmpE(Media(MediaNo), Move.Track.p.fm.p(4),
     *                   Et)
         cTrack.p.fm.p(4) = cTrack.p.fm.p(4) - Et  ! muon
         call epe2p(cTrack)         ! adjust momentum
         call eppush(cTrack)        ! push
         if(Media(MediaNo).mu.MuPr .eq. 3) then
c              generate pair electrons; employ eppair
c              to do so, make cTrack a gamma of energy Et
            cTrack.p.fm.p(4) = Et
            cTrack.p.code = kphoton  ! this and next
            call epe2p(cTrack)       ! are not needed ; for safety
            call eppair
         endif
      elseif( Move.proc .eq. 'brem' ) then   
         call epmuBrsmpE(Media(MediaNo), Move.Track.p.fm.p(4),
     *                   Et)
         cTrack.p.fm.p(4) = cTrack.p.fm.p(4) - Et  ! muon
         call epe2p(cTrack)         ! adjust momentum
         call eppush(cTrack)        ! push
         if(Media(MediaNo).mu.MuBr .eq. 3) then
c             generate brems gamma; no deflection
            cTrack.p.fm.p(4) = Et
            cTrack.p.code = kphoton
            call epe2p(cTrack)  ! adjust momentum
            call eppush(cTrack) ! push
         endif
      elseif( Move.proc .eq. 'nuci' ) then   
         call epmuNsmpE(Media(MediaNo), Move.Track.p.fm.p(4),
     *                   Et)
         cTrack.p.fm.p(4) = cTrack.p.fm.p(4) - Et  ! muon
         call epe2p(cTrack)         ! adjust momentum
         call eppush(cTrack)        ! push
         if(Media(MediaNo).mu.MuNI .eq. 3 .and. Et .gt. 150.d-3) then
c             generate gamma-N interaction; employ gamma interaction
c             routine 
            cTrack.p.fm.p(4) = Et
            cTrack.p.code = kphoton
            call epe2p(cTrack)  ! adjust momentum
c            mediateAeff=Media(MediaNo).Aeff
c            mediateZeff=Media(MediaNo).Zeff
c
            call ep2cosPtcl( cTrack.p )
            call ep2cosCond2(Media(MediaNo).Aeff,
     *                       Media(MediaNo).Zeff)
            call cphotop        ! Cosmos function
            call eppushPtcl(cTrack) ! use pos. info from this ptcl
         endif
      endif   
      end
